@@ -61,7 +61,7 @@ def embedops_cli(ctx, debug):
             fg="magenta",
         )
         click.secho(
-            f"\nWelcome to EmbedOps CLI",
+            "\nWelcome to EmbedOps CLI",
             err=False,
             fg="magenta",
         )
